/**
 * itnclub 公共核心js文件
 */
var Common = function ($,window){
	return {
		noData: '<div class="am-pt-15 am-ft-center"><span class="am-ft-sm am-ft-gray">没有相关记录可以显示！</span></div>',
		/**
		 * 统一抽象的ajax方法
		 * dataType： 只能为json格式数据，如果返回的不是json格式，认为是异常信息
		 * @param options(Json Object) {
		 * 			url :请求地址
		 * 			type：请求类型，如post、get
		 * 			async：同步还是异常 默认true 表示异步
		 * 			callback：成功之后回调方法
		 * 			failure：出现异常时候回调方法
		 * 		}
		 * @returns
		 */
		urlConfig:{
			/*"console_url":"http://124.90.32.149:443/hytqh-front/"*/		//测试地址
			"console_url":"http://yyacdx2.yafco.com:443/yaqh-front/" //生产地址
		},

		ajax:function (options){
			$.ajax({
				url:options.url,
				type:options.type || "post",
				dataType:"json",
				async : (options.async != undefined) ? options.async : true,
				data : options.data || {},
				success : function(result) {
					if(result.success){
						callSuccess(options.callback,result);
					}else{
						callException(result);
					}
				},
				error:function (XMLHttpRequest, textStatus, errorThrown){
					if(XMLHttpRequest.readyState == 4 && (XMLHttpRequest.status == "200" || textStatus == "OK")){
						callError(options.failure,XMLHttpRequest.responseText);
					}else{
						$.dialog({
							content:"调用数据失败，请稍后再试。",
							title:"alert",
							ok:function(){
							}
						});
						//show({message:"调用数据失败，请稍后再试。"});
					}
				}
			});
		},
		/**
		 * 截取字符串
		 * @returns
		 */
		getParam:function (name) {
			var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)", "i");
			var r = window.location.search.substr(1).match(reg);
			if (r != null){
				return unescape(r[2]);
			}
			return null;
		},
		/**
		 * 展示普通弹出框
		 * @param options(Json Object){
		 * 		message:弹出层内容 jQuery对象或字符串
		 * 		fixed：是否固定最小高度和宽度，默认true 表示需要固定
		 * 			以下参数只在 fixed 为true时有效
		 *			width:最小宽度 单位：像素
		 * 			height：最小高度 单位：像素
		 * 		}
		 * @returns
		 */
		showAlert:function (options){
			var $m = options.message;
			var opts = $.extend({},options,{message:$m});
			if($.type($m) === "object"){//对象
				var css = position(options);
				$.extend(opts,{css:css});
			}
			show(opts);
		},
		showLoading:function (){
			show({message:$('<div class="loading"><img style="width: 30px; height: 30px;display: inline; vertical-align: middle" src="file:///android_asset/www/yacfq/images/loading.gif"/></div>'),onOverlay:false,css:{
				border:"0px"
			}});
		},
		/**
		 * 展示Iframe型对话框
		 * @param url
		 * @param options(Json Object) {
		 * 			width:初始宽度 单位：像素
		 * 			height：初始高度 单位：像素
		 * 			top：弹出框距离页面顶部的距离，单位：百分比
		 * 		}
		 * @returns
		 */
		showIframe:function (options){
			//默认宽度及高度
			var _popWidth = options.width || 640;
			var _popHeight =options.height || 100;
			//默认显示距离页面顶端高度百分百
			var _popTop = options.top || 20;
			//计算 宽度
			var _widowWidth = $(window).width();
			var _left = (_widowWidth - _popWidth) / 2 ;
			show.apply(this,[{
				message:'加载中...',
				css:{
					left : _left + 'px',
					width : _popWidth + 'px',
					height:_popHeight + 'px',
					top : _popTop + '%'
				},
				onBlock:function (){
					var $popWidow = $(this);
					var iframe = createIframe($popWidow);
					iframe.src=options.url;
					$popWidow.html(iframe);
					if(options.onBlock){
						options.onBlock($popWidow);
					}
				}
			}]);
		},
		/**
		 * 关闭弹出层
		 * @param onUnblock(Function) 关闭弹出层之后回调方法
		 * @returns
		 */
		closeAlert:function(onUnblock){
			close(onUnblock);
		},
		/**
		 * 获取COOKIE值
		 * @param getCookie(cookiename)
		 * @returns
		 */
		getCookie: function(cookie_name){
			var allcookies = document.cookie;
			var cookie_pos = allcookies.indexOf(cookie_name);   //索引的长度  
			// 如果找到了索引，就代表cookie存在,反之，就说明不存在。  
			if (cookie_pos != -1){
				// 把cookie_pos放在值的开始，只要给值加1即可。  
				cookie_pos += cookie_name.length + 1;      //这里我自己试过，容易出问题，所以请大家参考的时候自己好好研究一下。。。  
				var cookie_end = allcookies.indexOf(";", cookie_pos);
				if (cookie_end == -1){
					cookie_end = allcookies.length;
				}
				var value = unescape(allcookies.substring(cookie_pos, cookie_end)); //获取cookie的值。。。  
			}
			return value;
		},
		/**
		 * 根据 entrust_bs 获得买卖类别
		 */
		getEntrust_bsName:function(type)
		{
			if(type == 1)
			{
				return "买入";
			}else if(type == 2)
			{
				return "卖出";
			}
			else
			{
				return type;
			}
		}
	};
	//----------------内部方法------------------------------

	/**
	 * 异常信息返回时调用，显示错误信息
	 * @param result(JSON obj)
	 * @2016年7月26日11:37:02 孙安乐调整返回参数【success失败的情况下直接返回msg信息，暂定，如变动，则条件变更】
	 */
	function callException(result){
		show({message:result.msg,css:{width:'200px'}});
	}

	/**
	 * 出现异常时调用异常信息
	 * @param failure(Function) 失败时回调方法
	 * @param errorMessage(String) 异常信息
	 *
	 */
	function callError(failure,errorMessage){
		if(failure){
			failure(errorMessage);
		}else{
			show({message:errorMessage});
		}
	}

	/**
	 * 调用成功之后 处理方法
	 * @param callback(Function) 成功之后的回调方法
	 * @param result 请求返回的结果集
	 */
	function callSuccess(callback,result){
		if(callback){
			callback(result);
		}
	}
	/**
	 * 定位弹出层位置
	 * @param options(Json Object) 同 showAlert 参数说明
	 * @returns Json Object {
	 * 		left : 左边距离 单位：像素,
	 *		width : 宽度 单位：像素,
	 *		height: 高度 单位：像素,
	 *		top : 距离顶部距离 单位：百分比,
	 * }
	 */
	function position(options){
		var $m = options.message;
		//是否固定最小宽度及高度
		var fixed = options.fixed || true;
		//元素宽度
		var _popWidth = $m.width();
		//元素高度
		var _popHeight = $m.height();
		if(fixed){//处理固定情况的高度及宽度
			var _minWidth = options.width || 300;
			var _minHeight = options.height || 150;
			_popWidth = _popWidth < _minWidth ? _minWidth:_popWidth;
			_popHeight = _popHeight < _minHeight ? _minHeight:_popHeight;
		}
		//计算 高度和宽度
		var _widowWidth = $(window).width();
		//Loading为要显示的div
		var _popLeft = (_widowWidth - _popWidth) / 2 ;
		var _windowHeight = $(window).height();
		var _top = (_windowHeight - _popHeight) / 2;
		//最小距离顶部30px;
		_top = _top < 30 ? 30 : _top;
		var _popTop = Math.floor(_top/_windowHeight * 100);
		_popTop = _popTop <  20 ? 20:_popTop;
		return {
			left : _popLeft + 'px',
			width : _popWidth + 'px',
			height:_popHeight + 'px',
			top : _popTop + '%'
		};
	}
	/**
	 * 真正显示弹出层的方法
	 * @params options{
	 * 		message:内容
	 * 		onBlock:function 显示alert之后调用的函数
	 * 		css:初始样式
	 * }
	 * @returns
	 */
	function show (options){
		var w=null;
		if(options.css!=undefined){
			var cw =  options.css.width||$(document).width()*0.3;
			w = ($(document).width()-(parseInt(cw)+20))/2;
		}else{
			w = ($(document).width()-150)/2;
		}
		var params = {
			message: options.message,
			overlayCSS : {
				opacity : 0.5,
				cursor:"default",
				"z-index":"100002"
			},
			css : $.extend({
				"min-width":"30%",
				"max-width":"80%",
				opacity :0.8,
				"word-break":"break-all",
				position : 'fixed',
				padding: "15px 10px",
				backgroundColor : "#525252",
				color:"#fff",
				border: "none",
				"border-radius": "10px",
				"box-shadow": "0px 1px 10px rgba(0, 0, 0, 0.6)",
				cursor:"auto",
				"z-index":"100003",
				"text-algin":"center",
				"left":w+"px"
			},options.css || {}),

			onBlock:options.onBlock || function(){}
		};
		if(options.onOverlay == undefined || options.onOverlay == true ){
			$.extend(params,{
				onOverlayClick:function (){
					close(options.onUnblock);
				}
			});
		}
		$.blockUI(params);
	}
	/**
	 * 关闭弹出层
	 * @param onUnblock{function} 关闭弹出框之后调用的方法
	 */
	function close (onUnblock){
		$.unblockUI({
			fadeOut:700,
			onUnblock:onUnblock || function(){}
		});
	}
	/**
	 * 创建一个iframe，用于展示弹出层内容
	 * @param $popWidow(jQuery Object) 弹出框对象
	 */
	function createIframe($popWidow){
		var iframe = document.createElement("iframe");
		iframe.setAttribute("frameborder", "0", 0);
		iframe.width="100%";
		iframe.scrolling="no";
		iframe.height="100%";
		if (iframe.attachEvent){
			iframe.attachEvent("onload", function (){adaptiveHeight($popWidow,iframe);});
		} else {
			iframe.onload = function (){adaptiveHeight($popWidow,iframe);};
		}
		return iframe;
	}

	/**
	 * 弹出层根据iframe 自适应高度
	 * @param $popWidow(jQuery Object) 弹出框对象
	 * @param iframe(DOM Object) iframe 对象
	 */
	function adaptiveHeight($popWidow,iframe){
		$popWidow.css("height",getIframeBodyHeight(iframe));
	}
	/**
	 * 获取iframe的高度，兼容IE firefox chrome
	 * @param iframe(DOM Object) iframe 对象
	 */
	function getIframeBodyHeight(iframe){
		if(iframe.document){
			return $(iframe.document.body).height();
		}else if(iframe.contentDocument){
			return $(iframe.contentDocument.body).height();
		}

	}



	/**
	 * 判断返回值是对象还是数组
	 * @param 返回值 TRUE OR FALSE
	 */
	function isArray(arg){
		return Object.prototype.toString.call(arg) === '[object Array]';
	}

}(jQuery,window);